# Rocket Flight Dynamics Simulator

A Python library for simulating rocket flight dynamics and visualizing trajectory data.

## Features
- High-precision simulation of rocket flight dynamics

## Installation

### Pre-built binaries (recommended)

#### Windows 11
pip install PyRocketSim
Available for Python 3.10, 3.11, 3.12, and 3.13

#### Ubuntu 24.04
pip install PyRocketSim
Available for Python 3.10, 3.11, 3.12, and 3.13

### From source

#### Prerequisites
- Windows 11: Visual Studio 2022 with C++ tools
- Ubuntu/Debian: gcc, g++, make

## Test

Test.py you can find on [GitHub](https://github.com/LiptonVova/RocketPy)

## System Requirements

- OS: Windows 11 or Ubuntu 24.04
- Python: 3.10 or higher

## Dependencies

- numpy
- matplotlib

## License

MIT License

## Support

For issues and questions, please open an issue on our [GitHub repository](https://github.com/LiptonVova/RocketPy)